@@ -1,12 +1,14 @@
 import json
 import logging
+import os
 from functools import lru_cache
 from pathlib import Path
 from typing import Dict, List, Tuple
 
+from fuzzing_cli.fuzz.config import FuzzingOptions
 from fuzzing_cli.fuzz.exceptions import BuildArtifactsError
-from fuzzing_cli.fuzz.ide.generic import Contract, IDEArtifacts, Source
-from fuzzing_cli.fuzz.options import FuzzingOptions
+from fuzzing_cli.fuzz.ide.generic import IDEArtifacts
+from fuzzing_cli.fuzz.types import Contract, Source
 from fuzzing_cli.util import get_content_from_file
 
 LOGGER = logging.getLogger("fuzzing-cli")
@@ -16,12 +18,13 @@ class DapptoolsArtifacts(IDEArtifacts):
     def __init__(
         self,
         options: FuzzingOptions,
+        build_dir: Path,
+        sources_dir: Path,
         targets=None,
-        build_dir=None,
         map_to_original_source=False,
     ):
         super(DapptoolsArtifacts, self).__init__(
-            options, targets, build_dir or Path("./out"), map_to_original_source
+            options, targets, build_dir, sources_dir, map_to_original_source
         )
 
     @classmethod
@@ -30,7 +33,9 @@ class DapptoolsArtifacts(IDEArtifacts):
 
     @classmethod
     def validate_project(cls) -> bool:
-        pass
+        root_dir = Path.cwd().absolute()
+        files = list(os.walk(root_dir))[0][2]
+        return ".dapprc" in files
 
     @property
     def contracts(self) -> List[Contract]:
@@ -41,12 +46,12 @@ class DapptoolsArtifacts(IDEArtifacts):
         return self.fetch_data()[1]
 
     @staticmethod
-    def get_default_build_dir() -> str:
-        return "out"
+    def get_default_build_dir() -> Path:
+        return Path.cwd().joinpath("out")
 
     @staticmethod
-    def get_default_sources_dir() -> str:
-        return "src"
+    def get_default_sources_dir() -> Path:
+        return Path.cwd().joinpath("src")
 
     @staticmethod
     def _get_build_artifacts(build_dir) -> tuple:
@@ -71,7 +76,7 @@ class DapptoolsArtifacts(IDEArtifacts):
         return build_files_by_source_file, source_files
 
     @lru_cache(maxsize=1)
-    def fetch_data(self) -> Tuple[List[Contract], Dict[str, Source]]:
+    def process_artifacts(self) -> Tuple[Dict[str, List[Contract]], Dict[str, Source]]:
         """ example build_files_by_source_file
             {
                 'contracts': {
@@ -107,8 +112,6 @@ class DapptoolsArtifacts(IDEArtifacts):
 
         # ( 'contracts/Token.sol', {'allSourcePaths':..., 'deployedSourceMap': ... } )
         for source_file, contracts in build_files_by_source_file.items():
-            if source_file not in self._include:
-                continue
             result_contracts[source_file] = []
             for (contract_name, contract) in contracts.items():
                 # We get the build items from dapptools and rename them into the properties used by the FaaS
@@ -125,7 +128,7 @@ class DapptoolsArtifacts(IDEArtifacts):
                     result_contracts[source_file] += [
                         {
                             "sourcePaths": {
-                                source_file["id"]: file_path
+                                str(source_file["id"]): file_path
                                 for file_path, source_file in source_files.items()
                             },
                             "deployedSourceMap": contract["evm"]["deployedBytecode"][
@@ -138,7 +141,7 @@ class DapptoolsArtifacts(IDEArtifacts):
                             "bytecode": contract["evm"]["bytecode"]["object"],
                             "contractName": contract_name,
                             "mainSourceFile": source_file,
-                            "ignoredSources": list(ignored_sources),
+                            "ignoredSources": list(sorted(ignored_sources)),
                         }
                     ]
                 except KeyError as e:
@@ -167,4 +170,4 @@ class DapptoolsArtifacts(IDEArtifacts):
                 result_sources[source_file_path]["source"] = get_content_from_file(
                     source_file_path + ".original"
                 )
-        return self.flatten_contracts(result_contracts), result_sources
+        return result_contracts, result_sources
